@@ -2,7 +2,7 @@
 # Copyright (c) nexB Inc. and others. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/commoncode for support or download.
+# See https://github.com/aboutcode-org/commoncode for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
@@ -14,16 +14,16 @@ def set_re_max_cache(max_cache=1000000):
     libraries use a lot of regexes: therefore 100 is not enough to benefit from
     caching.
     """
-    import re
     import fnmatch
+    import re
 
-    remax = getattr(re, '_MAXCACHE', 0)
+    remax = getattr(re, "_MAXCACHE", 0)
     if remax < max_cache:
-        setattr(re, '_MAXCACHE', max_cache)
+        setattr(re, "_MAXCACHE", max_cache)
 
-    fnmatchmax = getattr(fnmatch, '_MAXCACHE', 0)
+    fnmatchmax = getattr(fnmatch, "_MAXCACHE", 0)
     if fnmatchmax < max_cache:
-        setattr(fnmatch, '_MAXCACHE', max_cache)
+        setattr(fnmatch, "_MAXCACHE", max_cache)
 
 
 set_re_max_cache()
